@@ -2,6 +2,7 @@
  * XRechnung Viewer Suite
  *
  * Copyright (C) 2023 Klaas Freitag <opensource@freisturz.de>
+ * Copyright (C) 2025 Stadt Treuchtlingen <sebastian.mogl@treuchtlingen.de>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,21 +31,34 @@ class XRechnung : public QObject
 {
     Q_OBJECT
 public:
+
+	/// Enumerate possible serialization formats
+	enum XRechnungFormat {
+		UNKNOWN,
+		UBL,
+		CII
+	};
+	
     explicit XRechnung(QObject *parent = nullptr);
 
     XRechnung(const QUrl& file, QObject *parent = nullptr);
     QDomDocument domDocument() const;
 
     QString html() const;
+    QUrl url() const;
 
     QString value(const QString& name) const;
-    QString fileName() { return _url.toLocalFile(); }
-    QString ublFileName() { return _tempfile.fileName(); }
+    QString fileName() const { return _url.toLocalFile(); }
+    QString intermediateFileName() const{ return _tempfile.fileName(); }
+
+    void exportPdf(const QString& path);
 
     // config keys as static members
     static QString SaxonJar;
+    static QString SaxonCii;
     static QString SaxonUbl;
     static QString SaxonHtml;
+    static QString SaxonPdf;
     static QString SaxonXsl;
 signals:
     void htmlAvailable();
@@ -52,17 +66,21 @@ signals:
 
 private slots:
     bool readDomDocument();
-    void createUbl();
+    void createIntermediate();
+    void detectFormat();
     void slotErrorOccurred(QProcess::ProcessError error);
     void slotDomFinished(int exitCode, QProcess::ExitStatus exitStatus);
     void createHtml();
     void slotHtmlFinished(int exitCode, QProcess::ExitStatus exitStatus);
+    void slotPdfFopFinished(int exitCode, QProcess::ExitStatus exitStatus);
+    void slotPdfXslFinished(int exitCode, QProcess::ExitStatus exitStatus);
 
 private:
-    QUrl           _url;
-    QString        _html;
-    QDomDocument   _domDoc;
-    QTemporaryFile _tempfile;
+    QUrl            _url;
+    QString         _html;
+    QDomDocument    _domDoc;
+    QTemporaryFile  _tempfile;
+    XRechnungFormat _format;
 };
 
 #endif // XRECHNUNG_H
