@@ -26,14 +26,17 @@
 namespace XRView {
 namespace Version {
 // Static content. Maintain values here.
-inline QString humanReadable() { return QStringLiteral("1.0"); }
+inline QString humanReadable() { return QStringLiteral("1.1"); }
 }
 
 namespace Info {
-inline QString authors() { return QStringLiteral("Klaas Freitag <opensource@freisturz.de>"); }
+inline QStringList authors() { return QStringList() << QStringLiteral("Klaas Freitag <opensource@freisturz.de>")
+                                                    << QStringLiteral("Sebastian Mogl (Stadt Treuchtlingen)"); }
 
 inline QString description() { return QObject::tr("Viewer for XRechnung documents."); }
 inline QString versions() { return QObject::tr("GNU General Public License Version 3"); }
+inline QString copyright() { return QStringLiteral("Klaas Freitag, Sebastian Mogl"); }
+inline QString copyrightYear() { return QObject::tr("2023-"); }
 }
 }
 
