@@ -22,6 +22,7 @@
 
 #include <QFormLayout>
 #include <QWidget>
+#include <QLabel>
 
 class XRechnung;
 
@@ -35,7 +36,7 @@ public:
     explicit XRWidget(QWidget *parent = nullptr);
     XRWidget(XRechnung *xr, QWidget *parent);
 
-    void addDisplay(const QString& xmlName, const QString& displayName);
+    QLabel* addDisplay(const QString& xmlName, const QString& displayName);
     XRechnung *xrechnung() { return _xr; }
 
 public slots:
